@@ -6,25 +6,25 @@ from myst_parser.main import MdParserConfig, default_parser
 
 def print_anchors(args=None):
     """ """
-    parser = argparse.ArgumentParser()
-    parser.add_argument(
+    arg_parser = argparse.ArgumentParser()
+    arg_parser.add_argument(
         "input",
         nargs="?",
         type=argparse.FileType("r"),
         default=sys.stdin,
         help="Input file (default stdin)",
     )
-    parser.add_argument(
+    arg_parser.add_argument(
         "-o",
         "--output",
         type=argparse.FileType("w"),
         default=sys.stdout,
         help="Output file (default stdout)",
     )
-    parser.add_argument(
+    arg_parser.add_argument(
         "-l", "--level", type=int, default=2, help="Maximum heading level."
     )
-    args = parser.parse_args(args)
+    args = arg_parser.parse_args(args)
     parser = default_parser(MdParserConfig(renderer="html", heading_anchors=args.level))
 
     def _filter_plugin(state):
