@@ -1,5 +1,6 @@
 import time
 from os import path
+from typing import Tuple
 
 from docutils import nodes
 from docutils.core import publish_doctree
@@ -20,14 +21,14 @@ SPHINX_LOGGER = logging.getLogger(__name__)
 class MystParser(Parser):
     """Docutils parser for Markedly Structured Text (MyST)."""
 
-    supported = ("md", "markdown", "myst")
+    supported: Tuple[str, ...] = ("md", "markdown", "myst")
     """Aliases this parser supports."""
 
-    settings_spec = ("MyST Parser Options", None, RstParser.settings_spec[2])
+    settings_spec = RstParser.settings_spec
     """Runtime settings specification.
 
     Defines runtime settings and associated command-line options, as used by
-    `docutils.frontend.OptionParser`.  This is a tuple of:
+    `docutils.frontend.OptionParser`.  This is a concatenation of tuples of:
 
     - Option group title (string or `None` which implies no group, just a list
       of single options).
@@ -43,7 +44,7 @@ class MystParser(Parser):
 
     def parse(
         self, inputstring: str, document: nodes.document, renderer: str = "sphinx"
-    ):
+    ) -> None:
         """Parse source text.
 
         :param inputstring: The source string to parse
